



.. image:: https://travis-ci.org/sonofeft/RocketUnits.svg?branch=master

.. image:: https://img.shields.io/pypi/v/RocketUnits.svg
        
.. image:: https://img.shields.io/badge/python-3.5|3.6|3.7|3.8|3.9-blue

.. image:: https://img.shields.io/pypi/l/RocketUnits.svg
    

RocketUnits Provides A Graphic User Interface (GUI) For Engineering Units Conversion.


See the Code at: `<https://github.com/sonofeft/RocketUnits>`_

See the Docs at: `<http://rocketunits.readthedocs.org/en/latest/>`_

See PyPI page at:`<https://pypi.python.org/pypi/rocketunits>`_

Aerospace scientists and engineers are often called upon to convert the values
of physical quantities from one set of units to another.

RocketUnits was created in order to fill that need.

**RocketUnits** provides units conversion for a number of physical unit categories.
Units categories include: Acceleration, Angle, AngVelocity, 
Acceleration, Angle, AngVelocity, 
Area, DeltaT, Density, ElementDensity, Energy, Specific Energy, Force, Frequency, 
Heat Capacity, Heat Transfer Coefficient, Isp, Length, Mass, MassFlow, 
Molecular Weight, Power, 
Pressure, Surface Tension, Temperature, Thermal Conductivity, Time, Velocity, 

Unit conversion can be performed either with the included GUI, or directly
from python by importing **RocketUnits**.


